```{eval-rst}
.. module:: gcell.rna
```

# RNA Module API Documentation

```{eval-rst}
.. currentmodule:: gcell.rna
```

This document provides an overview of the RNA module, which includes classes and methods for handling GENCODE gene annotations, GTF files, and gene data.

## Classes

```{eval-rst}
.. autosummary::
   :nosignatures:
   :toctree: ../generated/

   gencode.Gencode
   gtf.GTF
   gene.Gene
   gene.TSS
   gene.GeneExp
   gene.GeneSets
```
